@@ -64,7 +64,9 @@ def launch_qct(ui, repo, *extras, **opts):
         # You can specificy it's location in ~/.hgrc via
         #   [qct]
         #   path=
-        cmd = ui.config("qct", "path", "qct") + " --hg"
+        try:    udata = " -u %s" % opts['user'][-1]
+        except: udata = ''
+        cmd = ui.config("qct", "path", "qct") + udata + " --hg"
         os.system(cmd)
     else:
         import sys
@@ -76,7 +78,7 @@ def launch_qct(ui, repo, *extras, **opts):
             if vcs.initRepo(None, dispatch) != 0:
                 sys.exit()
 
-        # Pass along -I/-X options to Mercurial back-end
+        # Pass along -I/-X and --user options to Mercurial back-end
         vcs.pluginOptions(opts)
 
         app = QtGui.QApplication([])
