@@ -33,7 +33,7 @@ class CommitTool(QtGui.QWidget):
 
         self.ui = Ui_commitToolDialog()
         self.ui.setupUi(self)
-        self.setWindowFlags(QtCore.Qt.Window | QtCore.Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() | QtCore.Qt.WindowContextHelpButtonHint)
         self.setWindowTitle("Qct Commit Tool %s" % qct_version)
         self.ui.histButton = None
 
@@ -54,6 +54,16 @@ class CommitTool(QtGui.QWidget):
                 "Refresh Patch", None, QtGui.QApplication.UnicodeUTF8))
             self.commitButtonToolTip = "Refresh selected files in patch " + self.vcs.topPatchName()
             self.ui.cancelPushButton.setText("Exit")
+        # Support for merge commits (multiple parents for working directory)
+        elif 'merge' in self.vcs.capabilities() and self.vcs.isMerge():
+            self.ui.commitMsgBox.setTitle(QtGui.QApplication.translate("commitToolDialog",
+                "Merge Description", None, QtGui.QApplication.UnicodeUTF8))
+            self.ui.commitPushButton.setText(QtGui.QApplication.translate("commitToolDialog",
+                "Commit Merge Results", None, QtGui.QApplication.UnicodeUTF8))
+            self.ui.selectAllPushButton.setEnabled(False)
+            self.ui.fileListBox.setTitle(QtGui.QApplication.translate("commitToolDialog", 
+                "File list cannot be filtered when committing merge results",
+                None, QtGui.QApplication.UnicodeUTF8))
 
         # Recover persistent data
         settings = QtCore.QSettings('vcs', 'qct')
@@ -682,6 +692,11 @@ class CommitTool(QtGui.QWidget):
         if newCommitFlag:
             self.fileCheckState = {}
 
+        if 'merge' in self.vcs.capabilities() and self.vcs.isMerge():
+            merge = True
+        else:
+            merge = False
+
         self.ui.fileListWidget.clear()
         self.unknownFileList = []
         for itemName in self.filteredList:
@@ -698,6 +713,7 @@ class CommitTool(QtGui.QWidget):
             else:
                 listItem.setCheckState(QtCore.Qt.Unchecked)
                 self.fileCheckState[ fileName ] = False
+            if merge: listItem.setFlags(QtCore.Qt.ItemIsSelectable)
             self.ui.fileListWidget.addItem(listItem)
 
         # Display status (diff) of first item in list, and select it
