@@ -35,10 +35,10 @@ def findHg():
     return None
 
 class qctVcsHg:
-    def initRepo(self, argv, hgdispatch=None):
+    def initRepo(self, argv, hgdispatch=None, username=None):
         '''Initialize your revision control system, open repository'''
 
-        self.commitname = None
+        self.commitname = username
 
         # If we're running from the qct.py extension, we can call directly into mercurial
         if hgdispatch:
@@ -57,6 +57,8 @@ class qctVcsHg:
             print err
             return -1
 
+        self.parents = self.hgcmd(['parents', '-q'])[0].splitlines()
+
         if os.getcwd() == self.repoRoot:
             self.runningFromRoot = True
         else:
@@ -73,7 +75,8 @@ class qctVcsHg:
                 'rename',      # VCS supports revisioned renames (fileMoveDetected)
                 'symlink',     # VCS supports symlinks
                 'patchqueue',  # VCS supports patch queue (isPatchQueue, topPatchName)
-                'progressbar'] # back-end supports a progress bar
+                'progressbar', # back-end supports a progress bar
+                'merge']       # VCS supports merges (isMerge)
 
         self.cmdLineOptions = []
 
@@ -221,6 +224,10 @@ class qctVcsHg:
         '''Return true if Mercurial Queue patches are applied'''
         return self.isPatchQ
 
+    def isMerge(self):
+        '''Return true if working directory has two parents'''
+        return len(self.parents) > 1
+
     def topPatchName(self):
         '''Return name of top patch (being refreshed)'''
         output = self.hgcmd(['qtop'], okresults=[0,1])[0]
@@ -244,7 +251,7 @@ class qctVcsHg:
         # Cache changes in the working directory (parse and store hg diff).  The paths reported
         # by diff are always relative to the repo root, so if we're running outside of the root
         # directory there is no point in trying to pre-cache diffs.
-        if self.runningFromRoot:
+        if self.runningFromRoot and len(self.parents) == 1:
             diff = self.hgcmd(['diff', '--show-function'] + self.cmdLineOptions)[0]
             (addedList, removedList, modifiedList, self.wdDiffCache) = scanDiffOutput(diff)
 
@@ -321,7 +328,14 @@ class qctVcsHg:
 
         # For revisioned files, we use hg diff
         if type in ['A', 'M', 'R']:
-            text = self.hgcmd(['diff', '--show-function', fileName])[0]
+            if len(self.parents) > 1:
+                text = "\n= Diff to first parent %s\n" % self.parents[0]
+                text += self.hgcmd(['diff', '--show-function', fileName])[0]
+                otherparentrev = self.parents[1].split(':')[0]
+                text += "\n= Diff to second parent %s\n" % self.parents[1]
+                text += self.hgcmd(['diff', '--show-function', '--rev', otherparentrev, fileName])[0]
+            else:
+                text = self.hgcmd(['diff', '--show-function', fileName])[0]
             self.wdDiffCache[fileName] = text
             return text
 
@@ -366,7 +380,10 @@ class qctVcsHg:
             note = bFileName + " has been added to revision control or is a rename target, but has never been commited."
             return note + linesep + text
         elif type == 'M':
-            note = bFileName + " has been modified in your working directory."
+            if len(self.parents) > 1:
+                note = bFileName + " has been merged in your working directory."
+            else:
+                note = bFileName + " has been modified in your working directory."
             return note + linesep + text
         elif type == '?':
             note = bFileName + " is not currently tracked. If commited, it will be added to revision control."
@@ -491,6 +508,12 @@ class qctVcsHg:
             self.hgcmd(['qrefresh', '-l', filename] + commitFileNames)
             print self.topPatchName() + " refreshed with %d file(s): %s" \
                     % (len(commitFileNames), ', '.join(commitFileNames))
+        elif len(self.parents) > 1:
+            if self.commitname:
+                self.hgcmd(['commit', '-u', self.commitname, '-l', filename])
+            else:
+                self.hgcmd(['commit', '-l', filename])
+            print "Merge results commited" 
         else:
             if self.commitname:
                 self.hgcmd(['commit', '-u', self.commitname, '-l', filename] + commitFileNames)
